@@ -120,7 +120,7 @@ class ListingResource:
         response = self.session.request(endpoint, "PUT", json=data)
         return Inventory(**response)
 
-    def get_listings_by_listing_ids(self, listing_ids: List[int], includes: str = ""):
+    def get_listings_by_listing_ids(self, listing_ids: List[int], includes: str = "", _as="pydantic"):
         params = {
             "listing_ids":",".join(list(map(str, listing_ids))),
             "includes":includes
@@ -128,7 +128,10 @@ class ListingResource:
         endpoint = "listings/batch"
         
         response = self.session.request(endpoint, params=params)
-        return Response[Listing](**response)
+        if _as == "pydantic":
+            
+            return Response[Listing](**response)
+        return response
     
     def get_listings_by_return_policy_id(self, return_policy_id: int, shop_id: int):
         endpoint = f"shops/{shop_id}/policies/return/{return_policy_id}/listings"
